Learn R Programming

dateutils (version 0.1.5)

any_finite: Rows with finite values

Description

Return indexes of rows with at least one finite value

Usage

any_finite(Y)

Arguments

Y

matrix like data object

Value

Indexes of rows with at least one finite value

Examples

Run this code
# NOT RUN {
X <- matrix(1,10,2)
X[3,] <- NA
any_finite(X)
# }

Run the code above in your browser using DataLab