powered by
Return a logical indicating whether data at given dates can be seasonally adjusted using seas()
can_seasonal(dates)
dates
A logical variable indicating whether data can be seasonally adjusted
# NOT RUN { can_seasonal(fred$ref_date[1:20]) ## TRUE # }
Run the code above in your browser using DataLab