Learn R Programming

dateutils (version 0.1.5)

end_of_year: End of Year

Description

Find the end of year for a vector of dates

Usage

end_of_year(dates)

Arguments

dates

Transition matrix from a VAR model

Value

The last day of the year for the dates

Examples

Run this code
# NOT RUN {
end_of_year(as.Date("2019-09-15")) ## 2019-12-31
# }

Run the code above in your browser using DataLab