Learn R Programming

dateutils (version 0.1.5)

first_of_quarter: First of Quarter

Description

Find the first date in the quarter for a vector of dates

Usage

first_of_quarter(dates)

Arguments

dates

Transition matrix from a VAR model

Value

The first day of the quarter for the dates

Examples

Run this code
# NOT RUN {
first_of_quarter(as.Date("2019-9-15")) ## 2019-07-01
# }

Run the code above in your browser using DataLab