Learn R Programming

dateutils (version 0.1.5)

first_previous_quarter: First of previous quarter date

Description

Return the date of the first day of the previous quarter

Usage

first_previous_quarter(date)

Arguments

date

date value formated as.Date()

Value

The first day of the previous quarter of the date

Examples

Run this code
# NOT RUN {
first_previous_quarter(as.Date("2019-09-15")) ## 2019-04-01
# }

Run the code above in your browser using DataLab