powered by
Find the Friday in a given week from a sequence of Dates Vectors should be in as.Date() format
index_by_friday(dates)
vector of dates
The date of the Friday in the week of the given date
# NOT RUN { dates <- seq.Date(from = as.Date("2020-09-21"), by = "week", length.out = 10) fridays <- index_by_friday(dates) weekdays(fridays) # }
Run the code above in your browser using DataLab