powered by
Create dummy variables for unique numeric values in `x`
numdum(x)
Numeric vector
Dummy variables for each unique value in the data
# NOT RUN { numdum(c(3,3,5,3,4,3,5,4,4,5)) ## dummies for each of 3, 4, and 5 # }
Run the code above in your browser using DataLab