Learn R Programming

dateutils (version 0.1.5)

seas_df_wide: Seasonally adjust wide format data using seas()

Description

Seasonaly adjust multiple monthly or quarterly series in wide format using X-13 SEATS via seas()

Usage

seas_df_wide(df, sa_cols, x11 = FALSE, transfunc = "none")

Arguments

df

wide format dataframe

sa_cols

names or column indexes of series to seasonally adjust

x11

T/F, use x11 as opposed to X-13 SEATS

transfunc

Data transformation, one of `none` for no transformation, `auto` for automatic detection, or `log` for log transformation

Value

A list with data.frames `sa_factors` containing seasonal factors and `values_sa` containing seasonally adjusted data.

Examples

Run this code
# NOT RUN {
 
seas_df_wide(fred[series_name == "gdp constant prices"], sa_cols="value")
# }

Run the code above in your browser using DataLab