powered by
Spline fill missing observations from the first observation to the last, leaving NA observations in the head and tail
spline_fill(x)
data with missing observations
data with interpolated missing observations, except at head and tail, which remain NA
# NOT RUN { spline_fill_trend(c(NA,1,2,3,NA,5)) ## NA 1 2 3 4 5 # }
Run the code above in your browser using DataLab