powered by
Find the first date in the quarter for a vector of dates
first_of_quarter(dates)
Transition matrix from a VAR model
The first day of the quarter for the dates
# NOT RUN { first_of_quarter(as.Date("2019-9-15")) ## 2019-07-01 # }
Run the code above in your browser using DataLab