powered by
Return the date of the first day of the previous quarter
first_previous_quarter(date)
date value formated as.Date()
The first day of the previous quarter of the date
# NOT RUN { first_previous_quarter(as.Date("2019-09-15")) ## 2019-04-01 # }
Run the code above in your browser using DataLab